@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.0900';
+our $VERSION = '0.0901';
 
 use Carp;
 
@@ -68,6 +68,7 @@ sub parse {
 
     # Get the roman representation based on the scale position
     my $position = first_index { $_ eq $note } @notes;
+    # If the note is note in the scale find a new position and accidental
     my $accidental;
     if ( $position == -1 ) {
         ( $position, $accidental ) = _pos_acc( $note, $position, \@notes );
@@ -88,9 +89,7 @@ sub parse {
     # Add any accidental found in a non-scale note
     $roman = $accidental . $roman if $accidental;
 
-    if ( $decorator =~ /Maj/ || $decorator =~ /min/ ) {
-        # Move Maj or min over one
-        $decorator =~ s/(Maj|min)/ $1/;
+    if ( $decorator =~ /maj/i || $decorator =~ /min/i ) {
         $decorator = lc $decorator;
     }
     else {
@@ -123,14 +122,19 @@ sub _pos_acc {
 
     my $accidental;
 
+    # If the note has no accidental...
     if ( length($note) == 1 ) {
+        # Find the scale position of the closest note
         $position = first_index { $_ =~ /$note/ } @$notes;
+        # Get the accidental of the scale note
         ( $accidental = $notes->[$position] ) =~ s/^[A-G](.)$/$1/;
+        # TODO: Why?
         $accidental = $accidental eq '#' ? 'b' : '#';
     }
     else {
-        my $letter;
-        ( $letter, $accidental ) = $note =~ /^([A-G])(.)$/;
+        # Get the accidental of the given note
+        ( my $letter, $accidental ) = $note =~ /^([A-G])(.)$/;
+        # Get the scale position of the closest note
         $position = first_index { $_ eq $letter } @$notes;
     }
 
@@ -151,7 +155,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.0900
+version 0.0901
 
 =head1 SYNOPSIS
 
